@@ -1,3 +1,3 @@
 package IO::Moose::IO_MooseTest_Bad;
 
-SYNTAX ERROR
+sub SYNTAX_ERROR {
